@@ -59,6 +59,7 @@
 #include <QStandardPaths>
 #include <QStatusBar>
 #include <QString>
+#include <QScreen>
 #include <QTextStream>
 #include <QTimer>
 #include <QUrl>
@@ -113,7 +114,7 @@ KuickShow::KuickShow( const char *name )
     bool isDir = false; // true if we get a directory on the commandline
 
     // parse commandline options
-    QCommandLineParser* parser = reinterpret_cast<QCommandLineParser*>(qApp->property("cmdlineParser").value<void*>());
+    QCommandLineParser *parser = static_cast<QCommandLineParser *>(qApp->property("cmdlineParser").value<void *>());
 
     // files to display
     // either a directory to display, an absolute path, a relative path, or a URL
@@ -304,9 +305,6 @@ void KuickShow::initGUI( const QUrl& startDir )
     QAction *quit = KStandardAction::quit( this, SLOT(slotQuit()), coll);
     coll->addAction( "quit", quit );
 
-    // remove QString::null parameter -- ellis
-//    coll->readShortcutSettings( QString::null );
-
     // menubar
     QMenuBar *mBar = menuBar();
     QMenu *fileMenu = new QMenu( i18n("&File"), mBar );
@@ -328,12 +326,7 @@ void KuickShow::initGUI( const QUrl& startDir )
     editMenu->addSeparator();
     editMenu->addAction(coll->action("properties"));
 
-
-    // add the sorting menu and a separator into the View menu
-    KActionMenu *viewActionMenu = static_cast<KActionMenu*>( coll->action("view menu"));
-    viewActionMenu->menu()->addSeparator();
-    KActionMenu *sortingMenu = static_cast<KActionMenu*>( coll->action("sorting menu"));
-//    viewActionMenu->menu()->addAction(sortingMenu); //, 0 ); // on top of the menu
+    KActionMenu *viewActionMenu = static_cast<KActionMenu *>(coll->action("view menu"));
 
     QMenu *settingsMenu = new QMenu( i18n("&Settings"), mBar );
     settingsMenu->setObjectName( QString::fromLatin1( "settings" ) );
@@ -388,10 +381,10 @@ void KuickShow::initGUI( const QUrl& startDir )
     tBar->addSeparator();
     tBar->addAction(about);
 
+    mBar->addSeparator();
     KHelpMenu* help = new KHelpMenu(this, QString(), false);
     mBar->addMenu(help->menu());
 
-
     sblblUrlInfo = createStatusBarLabel(10);
     sblblMetaInfo = createStatusBarLabel(2);
 
@@ -587,11 +580,9 @@ bool KuickShow::showImage( const KFileItem& fi,
         // and the second isn't (e.g. because it is a pdf or something else,
         // Imlib can't load).
         ImageWindow *safeViewer = m_viewer;
-
-
         if ( !safeViewer->showNextImage( fi.url() ) ) {
             m_viewer = safeViewer;
-            delete safeViewer; // couldn't load image, close window
+            safeViewer->deleteLater(); // couldn't load image, close window
         }
         else {
             // safeViewer->setFullscreen( fullscreen );
@@ -711,7 +702,7 @@ void KuickShow::tryShowNextImage()
     if (!m_viewer)
         return;
 
-        if (!next.isNull())
+    if (!next.isNull())
         showImage(next, false);
     else
     {
@@ -796,8 +787,8 @@ void KuickShow::slotPrint()
     if ( items.isEmpty() )
         return;
 
-	KFileItemList::const_iterator it = items.constBegin();
-	const KFileItemList::const_iterator end = items.constEnd();
+    KFileItemList::const_iterator it = items.constBegin();
+    const KFileItemList::const_iterator end = items.constEnd();
 
     // don't show the image, just print
     ImageWindow *iw = new ImageWindow( 0, id, this );
@@ -1131,9 +1122,8 @@ void KuickShow::about()
 
     aboutWidget->adjustSize();
 
-    // code copied from KDialog::centerOnScreen() (KDE4)
-    QDesktopWidget* desktop = QApplication::desktop();
-    QRect screenRect = desktop->screenGeometry(desktop->screenNumber(this));
+    QScreen *screen = windowHandle()->screen();
+    const QRect screenRect = screen->geometry();
     aboutWidget->move(screenRect.center().x() - aboutWidget->width() / 2, screenRect.center().y() - aboutWidget->height() / 2);
 
     aboutWidget->show();
@@ -1183,7 +1173,8 @@ void KuickShow::saveProperties( KConfigGroup& kc )
     QStringList urls;
     QList<ImageWindow*>::ConstIterator it;
     for ( it = s_viewers.constBegin(); it != s_viewers.constEnd(); ++it ) {
-        const QUrl url = (*it)->currentFile()->url();
+        const QUrl url = (*it)->url();			// checks currentFile() internally
+        if (!url.isValid()) continue;			// no current file, ignore
         if ( url.isLocalFile() )
             urls.append( url.path() );
         else
@@ -1418,7 +1409,7 @@ void KuickShow::slotToggleInlinePreview(bool on)
 	} else {
 		iconSize = KIconLoader::SizeSmall;
 	}
-	fileWidget->setIconsZoom( iconSize );
+	fileWidget->setIconSize( iconSize );
 	fileWidget->setInlinePreviewShown(on);
     QAction *defaultInlinePreview = fileWidget->actionCollection()->action( "inline preview" );
     defaultInlinePreview->setChecked(on);
